@@ -1,3 +1,7 @@
+from dataclasses import dataclass, field
+from pathlib import Path
+from typing import Type, AnyStr, List, Optional
+from zipfile import ZipFile, ZIP_DEFLATED
 import imghdr
 import inspect
 import json
@@ -8,15 +12,12 @@ import shutil
 import stat
 import tempfile
 import warnings
-from dataclasses import dataclass
-from pathlib import Path
-from typing import Type, AnyStr, List, Optional
-from zipfile import ZipFile, ZIP_DEFLATED
 
 import pkg_resources
 import requests
 
-from .chai_bot import ChaiBot
+from chai_py.auth import get_auth
+from chai_py.chai_bot import ChaiBot
 
 MAX_SUPPORTED_MEMORY = 4096
 
@@ -30,20 +31,27 @@ class Metadata:
     image_url: str
     # The alphanumeric part of a hex color code. (E.g. ffffff)
     color: str
-    # Developer Unique ID.
-    developer_uid: str
     # Description of the bot.
     description: str
     # Python class (N.B. not object!) that inherits from ChaiBot.
     input_class: Type[ChaiBot]
 
+    # Developer Unique ID.
+    developer_uid: str = field(default_factory=lambda: get_auth().uid)
+
     # Total available memory for the bot in MB. This includes memory needed to store sources and data.
     memory: int = 256
 
-    def verify(self):
+    def verify(self, bot_file: Path):
         """Performs basic checks to ensure validity of the metadata."""
         assert isinstance(self.name, str)
-        assert len(self.name) >= 3, "Bot name has to be at least 3 characters"
+        assert len(self.name) >= 3, "Bot name has to be at least 3 characters."
+
+        assert len(self.description) > 0, "Bot has to have description."
+        assert self.input_class.__init__ is ChaiBot.__init__, \
+            "Do not override ChaiBot.__init__(). Override the setup() method instead."
+
+        assert not (bot_file.parent / "main.py").exists(), "Do not create a main.py file in your bot's root directory."
 
         try:
             verify_image_url(self.image_url)
@@ -58,21 +66,23 @@ class Metadata:
         assert self.memory <= MAX_SUPPORTED_MEMORY, f"Attribute .memory has to be less than or equal to {MAX_SUPPORTED_MEMORY} (found {self.memory})."
 
 
-def package(metadata: Metadata, requirements: Optional[List[str]] = None):
+def package(metadata: Metadata, requirements: Optional[List[str]] = None, path: Optional[str] = None):
     """Packages the chatbot into a single archive for deployment.
 
     Performs some preliminary checks on the metadata.
-    Creates a package.zip file in the directory containing the file that contains the bot class.
+    Creates a _package.zip file in the directory containing the file that contains the bot class
+    unless a path is provided.
 
     :param metadata:
     :param requirements:
+    :param path:
     :return:
     """
-    print("Running verification checks on metadata.")
-    metadata.verify()
-
     bot_file = Path(inspect.getfile(metadata.input_class))
 
+    print("Running verification checks on metadata.")
+    metadata.verify(bot_file)
+
     metadata_dict = {
         'name': metadata.name,
         'imageUrl': metadata.image_url,
@@ -116,10 +126,14 @@ def package(metadata: Metadata, requirements: Optional[List[str]] = None):
             write_valid_requirements_file(Path(temp_dir) / "requirements.txt", requirements)
 
         # Create zip
-        zip_path = bot_file.parent / "_package.zip"
-        with zip_path.open("wb") as f:
+        if path is None:
+            path = bot_file.parent / "_package.zip"
+        else:
+            path = Path(path)
+
+        with path.open("wb") as f:
             zipfile_from_folder(temp_dir, f)
-        print(f"Created zip package at {zip_path}.")
+        print(f"Created zip package at {path}.")
 
 
 def verify_image_url(url: str):
